@@ -14,31 +14,33 @@
 #' @format A tibble with a column for the 15 different fire events variables
 #'   including lon/lat coordinates.
 #' @examples
+#' \dontshow{
+#' mapme.biodiversity:::.copy_resource_dir(file.path(tempdir(), "mapme-data"))
+#' }
+#' \dontrun{
 #' library(sf)
 #' library(mapme.biodiversity)
 #'
-#' temp_loc <- file.path(tempdir(), "mapme.biodiversity")
-#' if (!file.exists(temp_loc)) {
-#'   dir.create(temp_loc)
-#'   resource_dir <- system.file("res", package = "mapme.biodiversity")
-#'   file.copy(resource_dir, temp_loc, recursive = TRUE)
-#' }
+#' outdir <- file.path(tempdir(), "mapme-data")
+#' dir.create(outdir, showWarnings = FALSE)
 #'
-#' (try(aoi <- system.file("extdata", "sierra_de_neiba_478140_2.gpkg",
+#' aoi <- system.file("extdata", "sierra_de_neiba_478140_2.gpkg",
 #'   package = "mapme.biodiversity"
 #' ) %>%
 #'   read_sf() %>%
 #'   init_portfolio(
 #'     years = 2021,
-#'     outdir = file.path(temp_loc, "res"),
+#'     outdir = outdir,
 #'     tmpdir = tempdir(),
 #'     add_resources = FALSE,
-#'     cores = 1,
 #'     verbose = FALSE
 #'   ) %>%
 #'   get_resources("nasa_firms", instrument = "VIIRS") %>%
 #'   calc_indicators("active_fire_properties") %>%
-#'   tidyr::unnest(active_fire_properties)))
+#'   tidyr::unnest(active_fire_properties)
+#'
+#' aoi
+#' }
 NULL
 
 #' Calculate active fire properties based on FIRMS
@@ -47,32 +49,29 @@ NULL
 #' properties of fire events occurred in the region of interest for
 #' years 2000-2021 (MODIS) and 2012-2021 (VIIRS).
 #'
-#' @param shp A single polygon for which to calculate the active fire properties
+#' @param x A single polygon for which to calculate the active fire properties
 #' @param nasa_firms The active fire vector resource (NASA - FIRMS)
-#' @param rundir A directory where intermediate files are written to.
 #' @param verbose A directory where intermediate files are written to.
-#' @param todisk Logical indicating whether or not temporary vector files shall
-#'   be written to disk
 #' @param ... additional arguments
 #' @return A tibble
 #' @keywords internal
+#' @include register.R
 #' @noRd
-.calc_active_fire_properties <- function(shp,
+.calc_active_fire_properties <- function(x,
                                          nasa_firms,
-                                         rundir = tempdir(),
                                          verbose = TRUE,
-                                         todisk = FALSE,
                                          ...) {
-
   # change quality flag to charachter to allow binding MODIS and VIIRS
-  nasa_firms <- lapply(nasa_firms, function(x){
-    x$confidence = as.character(x$confidence)
+  nasa_firms <- lapply(nasa_firms, function(x) {
+    x$confidence <- as.character(x$confidence)
     x
   })
   # row bind the frames
-  nasa_firms = dplyr::bind_rows(nasa_firms)
-  intersected <- suppressWarnings(st_intersection(nasa_firms, st_geometry(shp)))
-  if(nrow(intersected) == 0) return(NA)
+  nasa_firms <- dplyr::bind_rows(nasa_firms)
+  intersected <- suppressWarnings(st_intersection(nasa_firms, st_geometry(x)))
+  if (nrow(intersected) == 0) {
+    return(NA)
+  }
   coordinates <- st_coordinates(intersected)
   intersected <- dplyr::as_tibble(intersected)
   intersected <- dplyr::select(intersected, -geom)
@@ -82,3 +81,11 @@ NULL
     latitude = coordinates[, 2, drop = TRUE]
   )
 }
+
+register_indicator(
+  name = "active_fire_properties",
+  resources = list(nasa_firms = "vector"),
+  fun = .calc_active_fire_properties,
+  arguments = list(),
+  processing_mode = "asset"
+)
