@@ -19,27 +19,25 @@
 #' @keywords indicator
 #' @format A tibble with a column for years and treecover (in ha)
 #' @examples
-#' if (Sys.getenv("NOT_CRAN") == "true") {
+#' \dontshow{
+#' mapme.biodiversity:::.copy_resource_dir(file.path(tempdir(), "mapme-data"))
+#' }
+#' \dontrun{
 #' library(sf)
 #' library(mapme.biodiversity)
 #'
-#' temp_loc <- file.path(tempdir(), "mapme.biodiversity")
-#' if (!file.exists(temp_loc)) {
-#'   dir.create(temp_loc)
-#'   resource_dir <- system.file("res", package = "mapme.biodiversity")
-#'   file.copy(resource_dir, temp_loc, recursive = TRUE)
-#' }
+#' outdir <- file.path(tempdir(), "mapme-data")
+#' dir.create(outdir, showWarnings = FALSE)
 #'
-#' (try(aoi <- system.file("extdata", "sierra_de_neiba_478140_2.gpkg",
+#' aoi <- system.file("extdata", "sierra_de_neiba_478140_2.gpkg",
 #'   package = "mapme.biodiversity"
 #' ) %>%
 #'   read_sf() %>%
 #'   init_portfolio(
 #'     years = 2016:2017,
-#'     outdir = file.path(temp_loc, "res"),
+#'     outdir = outdir,
 #'     tmpdir = tempdir(),
 #'     add_resources = FALSE,
-#'     cores = 1,
 #'     verbose = FALSE
 #'   ) %>%
 #'   get_resources(
@@ -47,7 +45,9 @@
 #'     vers_treecover = "GFC-2021-v1.9", vers_lossyear = "GFC-2021-v1.9"
 #'   ) %>%
 #'   calc_indicators("treecover_area", min_size = 1, min_cover = 30) %>%
-#'   tidyr::unnest(treecover_area)))
+#'   tidyr::unnest(treecover_area)
+#'
+#' aoi
 #' }
 NULL
 
@@ -59,25 +59,24 @@ NULL
 #' forest pixels. Patches below this threshold will not be considered as forest
 #' area.
 #'
-#' @param shp A single polygon for which to calculate the tree cover statistic
+#' @param x A single polygon for which to calculate the tree cover statistic
 #' @param gfw_treecover The treecover 2000 resource from GFW
 #' @param gfw_lossyear The lossyear resource from GFW
 #' @param min_size The minimum size of a forest patch in ha.
 #' @param min_cover The minimum threshold of stand density for a pixel to be
 #'   considered forest in the year 2000.
-#' @param rundir A directory where intermediate files are written to.
 #' @param verbose A directory where intermediate files are written to.
 #' @param ... additional arguments
 #' @return A tibble
 #' @importFrom stringr str_sub
 #' @keywords internal
+#' @include register.R
 #' @noRd
-.calc_treecover_area <- function(shp,
+.calc_treecover_area <- function(x,
                                  gfw_treecover,
                                  gfw_lossyear,
                                  min_size = 10,
                                  min_cover = 35,
-                                 rundir = tempdir(),
                                  verbose = TRUE,
                                  ...) {
   # initial argument checks
@@ -86,7 +85,7 @@ NULL
     return(NA)
   }
   # retrieve years from portfolio
-  years <- attributes(shp)$years
+  years <- attributes(x)$years
 
   if (any(years < 2000)) {
     warning(paste("Cannot calculate treecover statistics ",
@@ -139,7 +138,7 @@ NULL
   )
   # rasterize the polygon
   polyraster <- rasterize(
-    vect(shp), gfw_treecover,
+    vect(x), gfw_treecover,
     field = 1, touches = TRUE
   )
   # mask gfw_treecover
@@ -221,3 +220,17 @@ NULL
   # return a data-frame
   tibble(years = years, treecover = as.vector(unlist(yearly_cover_values)))
 }
+
+register_indicator(
+  name = "treecover_area",
+  resources = list(
+    gfw_treecover = "raster",
+    gfw_lossyear = "raster"
+  ),
+  fun = .calc_treecover_area,
+  arguments = list(
+    min_size = 10,
+    min_cover = 35
+  ),
+  processing_mode = "asset"
+)
