@@ -39,6 +39,7 @@ NULL
 #' @param rundir A directory where intermediate files are written to.
 #' @param verbose A directory where intermediate files are written to.
 #' @keywords internal
+#' @include register.R
 #' @noRd
 .get_gfw_lossyear <- function(x,
                               vers_lossyear = "GFC-2021-v1.9",
@@ -83,3 +84,12 @@ NULL
   # return all paths to the downloaded files
   filenames
 }
+
+
+register_resource(
+  name = "gfw_lossyear",
+  type = "raster",
+  source = "https://data.globalforestwatch.org/documents/tree-cover-loss/explore",
+  fun = .get_gfw_lossyear,
+  arguments <- list(vers_lossyear = "GFC-2021-v1.9")
+)
