@@ -1,7 +1,5 @@
 library(testthat)
 library(mapme.biodiversity)
-library(pbapply)
 
-pboptions(type = "none")
 options(pillar.advice = FALSE)
 test_check("mapme.biodiversity")
