@@ -1,4 +1,5 @@
 test_that(".get_gfw_emissions works", {
+  skip_on_cran()
   aoi <- read_sf(
     system.file("extdata", "sierra_de_neiba_478140.gpkg",
       package = "mapme.biodiversity"
@@ -17,7 +18,6 @@ test_that(".get_gfw_emissions works", {
     years = 2000:2020,
     outdir = outdir,
     tmpdir = tmpdir,
-    cores = 1,
     add_resources = FALSE,
     verbose = FALSE
   )
@@ -33,17 +33,15 @@ test_that(".get_gfw_emissions works", {
   # adds test to check for multiple polygons in the same tile
   splitted_aoi <- st_as_sf(st_make_grid(aoi, n = 2))
   portfolio <- init_portfolio(splitted_aoi,
-                              years = 2000:2020,
-                              outdir = outdir,
-                              tmpdir = tmpdir,
-                              cores = 1,
-                              add_resources = FALSE,
-                              verbose = TRUE
+    years = 2000:2020,
+    outdir = outdir,
+    tmpdir = tmpdir,
+    add_resources = FALSE,
+    verbose = TRUE
   )
   attributes(portfolio)$testing <- TRUE
   expect_equal(
     .get_gfw_emissions(portfolio),
     "gfw_forest_carbon_gross_emissions_Mg_CO2e_px_20N_080W.tif"
   )
-
 })
