@@ -2,7 +2,7 @@ test_that(".get_nasa_srtm works", {
   skip_on_cran()
   aoi <- read_sf(
     system.file("extdata", "sierra_de_neiba_478140.gpkg",
-                package = "mapme.biodiversity"
+      package = "mapme.biodiversity"
     )
   )
   aoi <- suppressWarnings(st_cast(aoi, to = "POLYGON")[1, ])
@@ -15,41 +15,33 @@ test_that(".get_nasa_srtm works", {
   tmpdir <- tempdir()
 
   portfolio <- init_portfolio(aoi,
-                              years = 2000:2020,
-                              outdir = outdir,
-                              tmpdir = tmpdir,
-                              cores = 1,
-                              add_resources = FALSE,
-                              verbose = TRUE
+    years = 2000:2020,
+    outdir = outdir,
+    tmpdir = tmpdir,
+    add_resources = FALSE,
+    verbose = TRUE
   )
 
   # Add testing attribute in order to skip downloads
   attributes(portfolio)$testing <- TRUE
 
-  expect_error(
-    .get_nasa_srtm(portfolio),
-    "SSL certification"
-  )
-
-  skip("Disabled until SSL certification is renewed.")
   expect_equal(
-    suppressWarnings(.get_nasa_srtm(portfolio)),
-    "srtm_22_09.zip"
+    .get_nasa_srtm(portfolio),
+    "NASADEM_HGT_n18w072.tif"
   )
 
   # adds test to check for multiple polygons in the same tile
   splitted_aoi <- st_as_sf(st_make_grid(aoi, n = 2))
   portfolio <- init_portfolio(splitted_aoi,
-                              years = 2000:2020,
-                              outdir = outdir,
-                              tmpdir = tmpdir,
-                              cores = 1,
-                              add_resources = FALSE,
-                              verbose = TRUE
+    years = 2000:2020,
+    outdir = outdir,
+    tmpdir = tmpdir,
+    add_resources = FALSE,
+    verbose = TRUE
   )
   attributes(portfolio)$testing <- TRUE
   expect_equal(
-    suppressWarnings(.get_nasa_srtm(portfolio)),
-    "srtm_22_09.zip"
+    .get_nasa_srtm(portfolio),
+    "NASADEM_HGT_n18w072.tif"
   )
 })
